@@ -7,6 +7,8 @@ from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
 from django.utils import importlib
 
+from . import safe_settings
+
 PY3 = sys.version > "3"
 
 
@@ -44,17 +46,10 @@ def load_path_attr(path):
     return attr
 
 
-STRIPE_PUBLIC_KEY = settings.STRIPE_PUBLIC_KEY
-INVOICE_FROM_EMAIL = getattr(
-    settings,
-    "DJSTRIPE_INVOICE_FROM_EMAIL",
-    "billing@example.com"
-)
-PAYMENTS_PLANS = getattr(settings, "DJSTRIPE_PLANS", {})
-PLAN_CHOICES = [
-    (plan, PAYMENTS_PLANS[plan].get("name", plan))
-    for plan in PAYMENTS_PLANS
-]
+STRIPE_PUBLIC_KEY = safe_settings.STRIPE_PUBLIC_KEY
+INVOICE_FROM_EMAIL = safe_settings.INVOICE_FROM_EMAIL
+PAYMENTS_PLANS = safe_settings.PAYMENTS_PLANS
+PLAN_CHOICES = safe_settings.PLAN_CHOICES
 
 
 DEFAULT_PLAN = getattr(
