@@ -24,6 +24,7 @@ from .models import Event
 from .models import EventProcessingException
 from .settings import PLAN_LIST
 from .settings import PY3
+from .settings import User
 from .sync import sync_customer
 
 
@@ -189,6 +190,19 @@ class ChangePlanView(LoginRequiredMixin,
             except stripe.StripeError as e:
                 self.error = e.message
                 return self.form_invalid(form)
+            except Exception as e:
+                raise e
             return self.form_valid(form)
         else:
             return self.form_invalid(form)
+
+
+######### Web services
+class CheckAvailableUserAttributeView(View):
+
+    def get(self, request, *args, **kwargs):
+        attr_name = self.kwargs['attr_name']
+        not_available = User.objects.filter(
+                **{attr_name: request.GET.get("v", "")}
+        ).exists()
+        return HttpResponse(json.dumps(not not_available))
